imodels.rule_set API documentation
Description: Generic class for models that take the form of a set of (potentially overlapping) rules.

# Module `imodels.rule_set`

Generic class for models that take the form of a set of (potentially overlapping) rules.

Expand source code

    '''Generic class for models that take the form of a set of (potentially overlapping) rules.
    '''

## Sub-modules

`imodels.rule_set.boosted_rules`
`imodels.rule_set.brs`

  Original implementation at https://github.com/wangtongada/BOA

`imodels.rule_set.fplasso`
`imodels.rule_set.fpskope`
`imodels.rule_set.rule_fit`

  Linear model of tree-based decision rules based on the rulefit algorithm from Friedman and Popescu …

`imodels.rule_set.rule_set`
`imodels.rule_set.skope_rules`

  Skope-rules aims at learning logical, interpretable rules for "scoping" a target class, i.e. detecting with high precision instances of this class …

`imodels.rule_set.slipper`
`imodels.rule_set.slipper_util`